@@ -1,9 +1,11 @@
 try:
     from normatrix.source.file_parser import CFileParse
     from normatrix.source.config import TypeLine
+    from normatrix.source.custom_regex import re_sub, re_search
 except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
     from normatrix.normatrix.source.config import TypeLine
+    from normatrix.source.custom_regex import re_sub, re_search
 
 import re
 
@@ -17,9 +19,9 @@ def check(context, file: CFileParse) -> (int, int, list):
         line = file.sub_parsedline[i]
         if line[0] == TypeLine.COMMENT:
             continue
-        ll = re.sub('\/\/.*', '', line[1])
-        ll = re.sub("'(.)'", '', ll)
-        m = re.search(",\S", ll)
+        ll = re_sub('\/\/.*', '', line[1], timeout=0.1)
+        ll = re_sub("'(.)'", '', ll, timeout=0.1)
+        m = re_search(",\S", ll, timeout=0.1)
         if m != None:
             list_error.append(
                     (i + 1, f"need a space after a comma ({ll[m.start():]})")
