@@ -3,9 +3,8 @@ try:
 except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
 
-def check(context, file: CFileParse) -> (int, int):
+def check(context, file: CFileParse) -> (int, int, list):
     if file.real_parsedline[-1][1] != "":
-        print(f"{file.basename}: need a line break at end of file")
-        return (1, 2)
+        return (1, 2, [(len(file.real_parsedline), "need a line break at end of file")])
     else:
-        return (0, 2)
+        return (0, 2, [])
